/* ===evalM.c===
 * 
 * evaluates M(x,y,z,u,v) from hep-ph/0501132
 *
 * takes the following arguments
 *
 *   x, y, z, u, v squared masses
 *   s momentum squared
 *   qq renormalisation scale squared
 *
 * prints the value of M(x,y,z,u,v) to stdout
 *
 */

#include <stdio.h>
#include "tsil.h"

long double strtold( const char *, char** );

int main( int argc, char *argv[] )
{
  TSIL_DATA foo;
  TSIL_REAL x, y, z, u, v;
  TSIL_REAL s, qq;
  TSIL_COMPLEX M;
  if( argc != 8 )
    TSIL_Error( "EvalM", 
                "Need 7 arguments: m1^2, m2^2, m3^2, m4^2, m5^2, s, mu^2", 1);

  x = (TSIL_REAL) strtold( argv[1], (char **) NULL );
  y = (TSIL_REAL) strtold( argv[2], (char **) NULL );
  z = (TSIL_REAL) strtold( argv[3], (char **) NULL );
  u = (TSIL_REAL) strtold( argv[4], (char **) NULL );
  v = (TSIL_REAL) strtold( argv[5], (char **) NULL );

  s = (TSIL_REAL) strtold( argv[6], (char **) NULL );
  qq = (TSIL_REAL) strtold( argv[7], (char **) NULL );

  TSIL_SetParameters( &foo, x, y, z, u, v, qq );
  TSIL_Evaluate( &foo, s );

  M = TSIL_GetFunction( &foo, "M" );

  printf( "%lf + %lf I\n", (double) creal(M), cimag(M) );

  return 0;
}
