/* ===evalT.c===
 * 
 * evaluates T(u,x,v) from hep-ph/0501132
 *
 * takes the following arguments
 *
 *   u, x, v squared masses
 *   s momentum squared
 *   qq renormalisation scale squared
 *
 * prints the value of T(u,x,v) to stdout
 *
 */

#include <stdio.h>
#include "tsil.h"

long double strtold( const char *, char** );

int main( int argc, char *argv[] )
{
  TSIL_DATA foo;
  TSIL_REAL u, x, v;
  TSIL_REAL s, qq;
  TSIL_COMPLEX Tuxv;
  if( argc != 6 )
    TSIL_Error( "EvalT", "Need 5 arguments: m1^2, m2^2, m3^2, s, mu^2", 1);

  u = (TSIL_REAL) strtold( argv[1], (char **) NULL );
  x = (TSIL_REAL) strtold( argv[2], (char **) NULL );
  v = (TSIL_REAL) strtold( argv[3], (char **) NULL );

  s = (TSIL_REAL) strtold( argv[4], (char **) NULL );
  qq = (TSIL_REAL) strtold( argv[5], (char **) NULL );

  TSIL_SetParametersST( &foo, x, u, v, qq );
  TSIL_Evaluate( &foo, s );

  Tuxv = TSIL_GetFunction( &foo, "Tuxv" );

  printf( "%lf + %lf I\n", (double) creal(Tuxv), cimag(Tuxv) );

  return 0;
}
